@@ -1,4 +1,4 @@
-// $Id: openMSXController.cpp 9649 2009-04-28 04:14:53Z mfeingol $
+// $Id: openMSXController.cpp 11273 2010-02-16 18:35:13Z m9710797 $
 // openMSXController.cpp: implementation of the openMSXController class.
 //
 //////////////////////////////////////////////////////////////////////
@@ -215,7 +215,7 @@ void openMSXController::HandleParsedOutput(wxCommandEvent &event)
 				if ((lastcmd.Mid(0,5) != wxT("plug ")) || (lastcmd.Find(' ',true) == 4) ||
 					(lastcmd.Mid(5,lastcmd.Find(' ',true)-5)!= data->name)) {
 						m_appWindow->m_videoControlPage->UpdateSetting (data->name, data->contents);
-						executeLaunch(NULL,43);
+						executeLaunch(NULL,m_relaunch);
 				}
 			}
 			else if (data->updateType == CatapultXMLParser::UPDATE_UNPLUG) {
@@ -223,7 +223,7 @@ void openMSXController::HandleParsedOutput(wxCommandEvent &event)
 				if ((lastcmd.Mid(0,7) != wxT("unplug ")) || /*(lastcmd.Find(' ',true) == 6)) {*/
 					(lastcmd.Mid(7)!= data->name)) {
 					m_appWindow->m_videoControlPage->UpdateSetting (data->name, data->contents);
-					executeLaunch(NULL,43);
+					executeLaunch(NULL,m_relaunch);
 				}
 			}
 			else if (data->updateType == CatapultXMLParser::UPDATE_MEDIA) {
@@ -584,8 +584,10 @@ void openMSXController::InitLaunchScript ()
 {
 	m_launchScriptSize = 0;
 	m_launchScript = new LaunchInstructionType [LAUNCHSCRIPT_MAXSIZE];
-	AddLaunchInstruction (wxT("update enable setting"),wxT(""),wxT(""),NULL,false);
-	AddLaunchInstruction (wxT("update enable led"),wxT(""),wxT(""),NULL,false);
+	// Use __catapult_update to support both old and new openmsx versions
+	AddLaunchInstruction (wxT("proc __catapult_update { args } { if {[info command openmsx_update] != \"\"} { eval \"openmsx_update $args\" } else { eval \"update $args\" } }"), wxT(""),wxT(""),NULL,false);
+	AddLaunchInstruction (wxT("__catapult_update enable setting"),wxT(""),wxT(""),NULL,false);
+	AddLaunchInstruction (wxT("__catapult_update enable led"),wxT(""),wxT(""),NULL,false);
 	AddLaunchInstruction (wxT("set power on"),wxT("e"),wxT("power"),&openMSXController::UpdateSetting,true);
 	AddLaunchInstruction (wxT("unset renderer"),wxT("e"),wxT(""),NULL,true);
 	AddLaunchInstruction (wxT("@execute"),wxT(""),wxT(""),&openMSXController::EnableMainWindow,false);
@@ -593,7 +595,7 @@ void openMSXController::InitLaunchScript ()
 	AddLaunchInstruction (wxT("^info scale_algorithm"),wxT(""),wxT("ScalerAlgoSelector"),&openMSXController::FillComboBox,true);
 	AddLaunchInstruction (wxT("lindex [openmsx_info setting scale_factor] 2"),wxT(""),wxT("ScalerFactorSelector"),&openMSXController::FillRangeComboBox,true);
 	AddLaunchInstruction (wxT("^info accuracy"),wxT(""),wxT("AccuracySelector"),&openMSXController::FillComboBox,false);
-	AddLaunchInstruction (wxT("update enable media"),wxT(""),wxT(""),NULL,false);
+	AddLaunchInstruction (wxT("__catapult_update enable media"),wxT(""),wxT(""),NULL,false);
 	AddLaunchInstruction (wxT("info exist frontswitch"),wxT(""),wxT("#"),&openMSXController::EnableFirmware,false);
 	AddLaunchInstruction (wxT("info exist firmwareswitch"),wxT(""),wxT("#"),&openMSXController::EnableFirmware,false);
 	AddLaunchInstruction (wxT("set renderer"),wxT(""),wxT("renderer"),&openMSXController::UpdateSetting,true);
@@ -630,6 +632,7 @@ void openMSXController::InitLaunchScript ()
 	AddLaunchInstruction (wxT("@checkfor pcminput"),wxT("1"),wxT(""),NULL,false);
 	AddLaunchInstruction (wxT("set audio-inputfilename"),wxT(""),wxT("audio-inputfilename"),&openMSXController::UpdateSetting,true);
 	AddLaunchInstruction (wxT("@execute"),wxT(""),wxT(""),&openMSXController::InitConnectorPanel,false);
+	m_relaunch = m_launchScriptSize; // !!HACK!!
 	AddLaunchInstruction (wxT("@execute"),wxT(""),wxT(""),&openMSXController::InitAudioConnectorPanel,false);
 //	AddLaunchInstruction (wxT("#info romtype"),wxT(""),wxT(""),&openMSXController::InitRomTypes,true);
 //	AddLaunchInstruction (wxT("#info_nostore romtype *"),wxT(""),wxT("*"),&openMSXController::SetRomDescription,true);
@@ -641,9 +644,9 @@ void openMSXController::InitLaunchScript ()
 	AddLaunchInstruction (wxT("set mute"),wxT(""),wxT("mute"),&openMSXController::UpdateSetting,true);
 	AddLaunchInstruction (wxT("plug cassetteport"),wxT(""),wxT("cassetteport"),&openMSXController::EnableCassettePort,false);
 	AddLaunchInstruction (wxT("join [cassetteplayer] \\n"),wxT(""),wxT(""),&openMSXController::SetCassetteMode,false);
-	AddLaunchInstruction (wxT("update enable plug"),wxT(""),wxT(""),NULL,false);
-	AddLaunchInstruction (wxT("update enable unplug"),wxT(""),wxT(""),NULL,false);
-	AddLaunchInstruction (wxT("update enable status"),wxT(""),wxT(""),NULL,false);
+	AddLaunchInstruction (wxT("__catapult_update enable plug"),wxT(""),wxT(""),NULL,false);
+	AddLaunchInstruction (wxT("__catapult_update enable unplug"),wxT(""),wxT(""),NULL,false);
+	AddLaunchInstruction (wxT("__catapult_update enable status"),wxT(""),wxT(""),NULL,false);
 }
 
 void openMSXController::AddLaunchInstruction (wxString cmd, wxString action,
@@ -1163,5 +1166,5 @@ int openMSXController::SetCassetteMode (wxString dummy, wxString data)
 
 void openMSXController::UpdateMixer()
 {
-	executeLaunch(NULL,43);
+	executeLaunch(NULL,m_relaunch);
 }
